@@ -98,7 +98,7 @@ class LVMMixin(driver.ExecuteMixin):
                       device_name, run_as_root=True)
 
     def _extend_container(self, share, device_name, size):
-        cmd = ['lvextend', '-L', '%sG' % size, '-n', device_name]
+        cmd = ['lvextend', '-L', '%sG' % size, '-r', device_name]
         self._try_execute(*cmd, run_as_root=True)
 
     def _deallocate_container(self, share_name):
@@ -108,7 +108,9 @@ class LVMMixin(driver.ExecuteMixin):
                               (self.configuration.lvm_share_volume_group,
                                share_name), run_as_root=True)
         except exception.ProcessExecutionError as exc:
-            if "not found" not in exc.stderr:
+            err_pattern = re.compile(".*failed to find.*|.*not found.*",
+                                     re.IGNORECASE)
+            if not err_pattern.match(exc.stderr):
                 LOG.exception("Error deleting volume")
                 raise
             LOG.warning("Volume not found: %s", exc.stderr)
@@ -256,11 +258,11 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
         return location
 
     def delete_share(self, context, share, share_server=None):
-        self._unmount_device(share)
+        self._unmount_device(share, raise_if_missing=False)
         self._delete_share(context, share)
         self._deallocate_container(share['name'])
 
-    def _unmount_device(self, share_or_snapshot):
+    def _unmount_device(self, share_or_snapshot, raise_if_missing=True):
         """Unmount the filesystem of a share or snapshot LV."""
         mount_path = self._get_mount_path(share_or_snapshot)
         if os.path.exists(mount_path):
@@ -268,9 +270,13 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
             try:
                 self._execute('umount', '-f', mount_path, run_as_root=True)
             except exception.ProcessExecutionError as exc:
-                if 'device is busy' in six.text_type(exc):
+                if 'device is busy' in exc.stderr.lower():
                     raise exception.ShareBusyException(
                         reason=share_or_snapshot['name'])
+                elif 'not mounted' in exc.stderr.lower():
+                    if raise_if_missing:
+                        LOG.error('Unable to find device: %s', exc)
+                        raise
                 else:
                     LOG.error('Unable to umount: %s', exc)
                     raise
@@ -379,7 +385,6 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
     def extend_share(self, share, new_size, share_server=None):
         device_name = self._get_local_path(share)
         self._extend_container(share, device_name, new_size)
-        self._execute('resize2fs', device_name, run_as_root=True)
 
     def revert_to_snapshot(self, context, snapshot, share_access_rules,
                            snapshot_access_rules, share_server=None):
@@ -430,7 +435,7 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
         return {'export_locations': exports}
 
     def delete_snapshot(self, context, snapshot, share_server=None):
-        self._unmount_device(snapshot)
+        self._unmount_device(snapshot, raise_if_missing=False)
 
         super(LVMShareDriver, self).delete_snapshot(context, snapshot,
                                                     share_server)
